summaryrefslogtreecommitdiffhomepage
path: root/cmake/modules/AddDatafile.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/modules/AddDatafile.cmake')
-rw-r--r--cmake/modules/AddDatafile.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/cmake/modules/AddDatafile.cmake b/cmake/modules/AddDatafile.cmake
index 6deda52..ea1c941 100644
--- a/cmake/modules/AddDatafile.cmake
+++ b/cmake/modules/AddDatafile.cmake
@@ -15,7 +15,7 @@
# additional directories with files that will also get included in the final datafile. In case of conflicts, files from
# source tree will be used. This is to allow working with binary assets located in source directory.
#
# To create the archive the Datafile.exe is used - for non-Windows platforms an emulator that can run it is required.
function(add_datafile DATAFILE_TARGET)
cmake_parse_arguments(
@@ -57,7 +57,7 @@ function(add_datafile DATAFILE_TARGET)
${CMAKE_COMMAND} -E chdir ${RESOURCE_DIRECTORY}
${CMAKE_COMMAND} -E env "${DATAFILE_VAR}='${DATAFILE_PATHS}'"
${CMAKE_CORSSCOMPILING_EMULATOR}
- $<TARGET_FILE:Datafile> $<SHELL_PATH:${DATAFILE_OUTPUT}> -mak
+ $<TARGET_FILE:dat> -cu $<SHELL_PATH:${DATAFILE_OUTPUT}> .
)
endforeach()
file(
@@ -73,7 +73,7 @@ function(add_datafile DATAFILE_TARGET)
${CMAKE_COMMAND} -E chdir ${DATAFILE_SOURCE}
${CMAKE_COMMAND} -E env "${DATAFILE_VAR}='${DATAFILE_PATHS}'"
${CMAKE_CORSSCOMPILING_EMULATOR}
- $<TARGET_FILE:Datafile> $<SHELL_PATH:${DATAFILE_OUTPUT}> -mak
+ $<TARGET_FILE:dat> -cu $<SHELL_PATH:${DATAFILE_OUTPUT}> .
)
add_custom_target(${DATAFILE_TARGET} ALL DEPENDS ${DATAFILE_OUTPUT})
endfunction()
@@ -15,7 +15,7 @@
# source tree will be used. This is to allow working with binary assets located in source directory.
#
-# To create the archive the Datafile.exe is used - for non-Windows platforms an emulator that can run it is required.
+# To create the archive the dat.exe is used - for non-Windows platforms an emulator that can run it is required.
function(add_datafile DATAFILE_TARGET)
cmake_parse_arguments(